@@ -443,22 +443,22 @@ GnomeUIInfo level_3_menu[] = {
 
 GnomeUIInfo game_menu[] = {
   { GNOME_APP_UI_SUBTREE, N_("_Novice"), NULL, level_1_menu,  NULL,NULL,
-    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BLANK, 
+    GNOME_APP_PIXMAP_STOCK, NULL, 
     (GdkModifierType) 0, GDK_CONTROL_MASK },
   { GNOME_APP_UI_SUBTREE, N_("_Medium"), NULL, level_2_menu,  NULL,NULL,
-    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BLANK, 
+    GNOME_APP_PIXMAP_STOCK, NULL, 
     (GdkModifierType) 0, GDK_CONTROL_MASK },
   { GNOME_APP_UI_SUBTREE, N_("_Advanced"), NULL, level_3_menu,  NULL,NULL,
-    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BLANK,
+    GNOME_APP_PIXMAP_STOCK, NULL,
     (GdkModifierType) 0, GDK_CONTROL_MASK },
   GNOMEUIINFO_MENU_SCORES_ITEM (score_cb, NULL),
   GNOMEUIINFO_SEPARATOR,
-  GNOMEUIINFO_MENU_EXIT_ITEM (quit_game_cb, NULL),
+  GNOMEUIINFO_MENU_QUIT_ITEM (quit_game_cb, NULL),
   GNOMEUIINFO_END
 };
 
 GnomeUIInfo help_menu[] = {
-  GNOMEUIINFO_HELP("gnotski"),
+  GNOMEUIINFO_HELP("gnotski"), 
   GNOMEUIINFO_MENU_ABOUT_ITEM(about_cb, NULL),
   GNOMEUIINFO_END
 };
@@ -485,15 +485,19 @@ int main (int argc, char **argv){
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain(GETTEXT_PACKAGE);
    
-  gnome_init_with_popt_table(APPNAME, VERSION, argc, argv, options, 0, NULL);
+  gnome_program_init (APPNAME, VERSION,
+                       LIBGNOMEUI_MODULE,
+                       argc, argv,
+                       GNOME_PARAM_POPT_TABLE, options,
+                       GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
   gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnotski-icon.png");
   client = gnome_master_client();
   gtk_object_ref(GTK_OBJECT(client));
   gtk_object_sink(GTK_OBJECT(client));
   
-  gtk_signal_connect(GTK_OBJECT (client), "save_yourself", 
+  g_signal_connect(GTK_OBJECT (client), "save_yourself", 
 		     GTK_SIGNAL_FUNC (save_state), argv[0]);
-  gtk_signal_connect(GTK_OBJECT(client), "die", GTK_SIGNAL_FUNC(quit_game_cb),
+  g_signal_connect(GTK_OBJECT(client), "die", GTK_SIGNAL_FUNC(quit_game_cb),
 		     argv[0]);
 
   create_window();
@@ -518,12 +522,15 @@ void create_window(){
   window = gnome_app_new(APPNAME, N_(APPNAME_LONG));
   gtk_window_set_policy(GTK_WINDOW(window), FALSE, FALSE, TRUE);
   gtk_widget_realize(window);
-  gtk_signal_connect(GTK_OBJECT(window), "delete_event", 
+  g_signal_connect(GTK_OBJECT(window), "delete_event", 
 		     GTK_SIGNAL_FUNC(quit_game_cb), NULL);
 }
 
 gint expose_space(GtkWidget *widget, GdkEventExpose *event){ 
-  gdk_draw_pixmap(widget->window, 
+if (buffer == NULL)
+	return FALSE;
+
+  gdk_draw_drawable(widget->window, 
                   widget->style->fg_gc[GTK_WIDGET_STATE(widget)], 
                   buffer, event->area.x, event->area.y, 
                   event->area.x, event->area.y, 
@@ -599,7 +606,7 @@ void gui_draw_pixmap(char *target, gint x, gint y){
   GdkRectangle area;
   int value;
   
-  gdk_draw_pixmap(buffer, space->style->black_gc, tiles_pixmap,
+  gdk_draw_drawable(buffer, space->style->black_gc, tiles_pixmap,
 		  get_piece_nr(target,x,y)*TILE_SIZE, 0, 
 		  x*TILE_SIZE, y*TILE_SIZE, TILE_SIZE, TILE_SIZE);
   if(get_piece_id(target,x,y)=='*'){
@@ -607,7 +614,7 @@ void gui_draw_pixmap(char *target, gint x, gint y){
       value = 20;
     else
       value = 22;
-    gdk_draw_pixmap(buffer, space->style->black_gc, tiles_pixmap,
+    gdk_draw_drawable(buffer, space->style->black_gc, tiles_pixmap,
 		    value*TILE_SIZE+10,10,
 		    x*TILE_SIZE+10, y*TILE_SIZE+10,8,8);
   }
@@ -616,20 +623,50 @@ void gui_draw_pixmap(char *target, gint x, gint y){
   gtk_widget_draw (space, &area);
 }
 
+void show_score_dialog (gint pos)
+{
+  GtkWidget *dialog;
+
+  dialog = gnome_scores_display (_(APPNAME_LONG), APPNAME, current_level, pos);
+  if (dialog != NULL) {
+    gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW(window));
+    gtk_window_set_modal (GTK_WINDOW(dialog), TRUE);
+  }
+}
+
 void score_cb(GtkWidget *widget, gpointer data){
-  gnome_scores_display (_(APPNAME_LONG), APPNAME, current_level, 0);
+  show_score_dialog (0);
+}
+
+void update_score_state ()
+{
+        gchar **names = NULL;
+        gfloat *scores = NULL;
+        time_t *scoretimes = NULL;
+	gint top;
+
+	top = gnome_score_get_notable(APPNAME, current_level, &names, &scores, &scoretimes);
+	if (top > 0) {
+		gtk_widget_set_sensitive (game_menu[3].widget, TRUE);
+		g_strfreev(names);
+		g_free(scores);
+		g_free(scoretimes);
+	} else {
+		gtk_widget_set_sensitive (game_menu[3].widget, FALSE);
+	}
 }
 
 void game_score(){
   gint pos;
   pos = gnome_score_log(moves,current_level,FALSE);
-  gnome_scores_display(_(APPNAME_LONG), APPNAME, current_level, pos);
+  update_score_state ();
+  show_score_dialog (pos);
 }
 
 gint configure_space(GtkWidget *widget, GdkEventConfigure *event){
   if(width>0){
     if(buffer)
-      gdk_pixmap_unref(buffer);
+      gdk_drawable_unref(buffer);
     buffer = gdk_pixmap_new(widget->window, widget->allocation.width, 
 			    widget->allocation.height, -1);
     redraw_all();
@@ -638,26 +675,24 @@ gint configure_space(GtkWidget *widget, GdkEventConfigure *event){
 }
 
 void create_space(){
-  gtk_widget_push_visual(gdk_rgb_get_visual ());
-  gtk_widget_push_colormap(gdk_rgb_get_cmap());
+  gtk_widget_push_colormap(gdk_rgb_get_colormap());
   space = gtk_drawing_area_new();
   gtk_widget_pop_colormap();
-  gtk_widget_pop_visual();
   gnome_app_set_contents(GNOME_APP(window),space);
   gtk_drawing_area_size(GTK_DRAWING_AREA(space),
 			TILE_SIZE*width,TILE_SIZE*height); 
   gtk_widget_set_events(space, GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK |
 			GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK);
   gtk_widget_realize(space);
-  gtk_signal_connect(GTK_OBJECT(space), "expose_event", 
+  g_signal_connect(GTK_OBJECT(space), "expose_event", 
                      GTK_SIGNAL_FUNC(expose_space), NULL);
-  gtk_signal_connect(GTK_OBJECT(space), "configure_event", 
+  g_signal_connect(GTK_OBJECT(space), "configure_event", 
                      GTK_SIGNAL_FUNC(configure_space), NULL);
-  gtk_signal_connect(GTK_OBJECT(space), "button_press_event", 
+  g_signal_connect(GTK_OBJECT(space), "button_press_event", 
                      GTK_SIGNAL_FUNC(button_press_space), NULL);
-  gtk_signal_connect (GTK_OBJECT(space),"button_release_event",
+  g_signal_connect (GTK_OBJECT(space),"button_release_event",
                       GTK_SIGNAL_FUNC(button_release_space), NULL);
-  gtk_signal_connect (GTK_OBJECT(space), "motion_notify_event",
+  g_signal_connect (GTK_OBJECT(space), "motion_notify_event",
                       GTK_SIGNAL_FUNC(button_motion_space), NULL);
   gtk_widget_show(space);
 }
@@ -666,15 +701,16 @@ void create_statusbar(){
   GtkWidget *move_label,*move_box;
   move_box = gtk_hbox_new(0, FALSE);
   move_label = gtk_label_new (_("Moves:"));
-  gtk_box_pack_start (GTK_BOX(move_box), move_label, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX(move_box), move_label, FALSE, FALSE, 6);
   move_value = gtk_label_new ("000");
-  gtk_box_pack_start (GTK_BOX(move_box), move_value, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX(move_box), move_value, FALSE, FALSE, 6);
   gtk_widget_show (move_label); gtk_widget_show (move_value); 
   gtk_widget_show (move_box);
 
   statusbar = gtk_statusbar_new();
   statusbar_id = gtk_statusbar_get_context_id(GTK_STATUSBAR(statusbar),
 					      APPNAME);
+  gtk_statusbar_set_has_resize_grip(GTK_STATUSBAR(statusbar),FALSE);
   gtk_box_pack_end(GTK_BOX(statusbar), move_box, FALSE, FALSE, 0);
   gnome_app_set_statusbar(GNOME_APP(window), statusbar);
   gtk_statusbar_push(GTK_STATUSBAR(statusbar), statusbar_id,APPNAME_LONG);
@@ -689,15 +725,25 @@ void load_image(){
   char *fname;
   GdkPixbuf *image;
 
-  fname = gnome_unconditional_pixmap_file("gnotski.png");
-  if(!g_file_exists(fname)) {
-    g_print(_("Could not find \'%s\' pixmap file\n"), fname); exit(1);
+  fname = gnome_program_locate_file(NULL, GNOME_FILE_DOMAIN_APP_PIXMAP, 
+	                                  "gnotski.png", FALSE, NULL);
+  if(g_file_test(fname, G_FILE_TEST_EXISTS)) {
+    image = gdk_pixbuf_new_from_file(fname, NULL);
+
+    gdk_pixbuf_render_pixmap_and_mask (image, &tiles_pixmap, NULL, 127);
+    gdk_pixbuf_unref(image);
+  } else {
+    GtkWidget *dialog;
+
+    dialog = gtk_message_dialog_new (NULL,
+		    GTK_DIALOG_MODAL,
+		    GTK_MESSAGE_ERROR,
+		    GTK_BUTTONS_OK,
+		    _("Could not find \'%s\' pixmap file\n"), fname);
+    gtk_dialog_run (GTK_DIALOG(dialog));
+
+    exit(1);
   }
-  image = gdk_pixbuf_new_from_file(fname, NULL);
-
-  gdk_pixbuf_render_pixmap_and_mask (image, &tiles_pixmap, NULL, 127);
-
-  gdk_pixbuf_unref(image);
   g_free(fname);
 }
 
@@ -710,7 +756,7 @@ void new_move() {
   char str[4];
   if(moves<999) moves++;
   sprintf(str,"%03d", moves);
-  gtk_label_set(GTK_LABEL(move_value), str);
+  gtk_label_set_text(GTK_LABEL(move_value), str);
 }
 
 
@@ -920,44 +966,41 @@ void new_game_cb(GtkWidget *widget, gpointer data){
   gtk_widget_realize(window);
 
   set_move(0);
+
+  update_score_state ();
 }
 
 void quit_game_cb(GtkWidget *widget, gpointer data){
   if(buffer)
-    gdk_pixmap_unref(buffer);
+    gdk_drawable_unref(buffer);
   if(tiles_pixmap)
-    gdk_pixmap_unref(tiles_pixmap);
+    gdk_drawable_unref(tiles_pixmap);
 
   gtk_main_quit();
 }
 
-static char *nstr(int n){
-  char buf[20]; sprintf(buf, "%d", n);
-  return strdup(buf);
-}
-
 static int save_state(GnomeClient *client,gint phase, 
                       GnomeRestartStyle save_style, gint shutdown,
                       GnomeInteractStyle interact_style, gint fast,
                       gpointer client_data){
-  char *argv[20];
-  int i;
+  gchar *argv[20];
+  gint i;
   gint xpos, ypos;
   
   gdk_window_get_origin(window->window, &xpos, &ypos);
   
   i = 0;
-  argv[i++] = (char *)client_data;
+  argv[i++] = (gchar *)client_data;
   argv[i++] = "-x";
-  argv[i++] = nstr(xpos);
+  argv[i++] = g_strdup_printf("%d",xpos);
   argv[i++] = "-y";
-  argv[i++] = nstr(ypos);
+  argv[i++] = g_strdup_printf("%d",ypos);
   
   gnome_client_set_restart_command(client, i, argv);
   gnome_client_set_clone_command(client, 0, NULL);
   
-  free(argv[2]);
-  free(argv[4]);
+  g_free(argv[2]);
+  g_free(argv[4]);
   return TRUE;
 }
 
@@ -966,15 +1009,31 @@ void level_cb(GtkWidget *widget, gpointer data){
 }
 
 void about_cb(GtkWidget *widget, gpointer data){
-  GtkWidget *about;
+  GdkPixbuf *pixbuf = NULL;
+  static GtkWidget *about = NULL;
   
   const gchar *authors[] = { "Lars Rydlinge", NULL };
-  gchar *documenters[] = {
-                          NULL
-                         };
+  gchar *documenters[] = { "Andrew Sobala (andrew@sobala.net)", NULL };
   /* Translator credits */
-  gchar *translator_credits = _("");
-  
+  gchar *translator_credits = _("translator_credits");
+
+  if (about != NULL) {
+    gtk_window_present (GTK_WINDOW(about));
+    return;
+  }
+  {
+	  char *filename = NULL;
+
+	  filename = gnome_program_locate_file (NULL,
+			  GNOME_FILE_DOMAIN_APP_PIXMAP,  ("gnotski-icon.png"),
+			  TRUE, NULL);
+	  if (filename != NULL)
+	  {
+		  pixbuf = gdk_pixbuf_new_from_file(filename, NULL);
+		  g_free (filename);
+	  }
+  }
+
   about = gnome_about_new(_(APPNAME_LONG), 
                           VERSION, 
                           "(C) 1999 Lars Rydlinge",
@@ -982,7 +1041,9 @@ void about_cb(GtkWidget *widget, gpointer data){
 			    "(Comments to: Lars.Rydlinge@HIG.SE)"), 
                           (const char **)authors, 
                           (const char **)documenters,
-                          (const char *)translator_credits,
-			  NULL);
+                          strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+			  pixbuf);
+  gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (window));
+  g_signal_connect (G_OBJECT (about), "destroy", G_CALLBACK (gtk_widget_destroyed), &about);
   gtk_widget_show(about);
 }
