@@ -260,7 +260,13 @@ set_score (int new_score)
 static void
 show_scores (guint pos)
 {
-	gnome_scores_display (_("The Same Gnome"), "same-gnome", NULL, pos);
+	GtkWidget *dialog;
+
+	dialog = gnome_scores_display (_("The Same Gnome"), "same-gnome", NULL, pos);
+	if (dialog != NULL) {
+		gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW(app));
+		gtk_window_set_modal (GTK_WINDOW(dialog), TRUE);
+	}
 }
 
 static void
@@ -640,10 +646,10 @@ game_quit_callback (GtkWidget *widget, void *data)
 		gint response;
 		
 		box = gtk_message_dialog_new (GTK_WINDOW (app),
-					     GTK_DIALOG_DESTROY_WITH_PARENT,
-					     GTK_MESSAGE_QUESTION,
-					     GTK_BUTTONS_NONE,
-					     _("Are you sure you want to quit?"));
+				GTK_DIALOG_DESTROY_WITH_PARENT,
+				GTK_MESSAGE_QUESTION,
+				GTK_BUTTONS_NONE,
+				_("Are you sure you want to quit Same Gnome?"));
 
 		gtk_dialog_add_buttons (GTK_DIALOG (box),
 						GTK_STOCK_CANCEL,
